package db

import (
	"applet/app/db/model"
	"applet/app/utils/logx"
	"reflect"
	"xorm.io/xorm"
)

type CentralKitchenForSchoolUserWithDayDb struct {
	Db         *xorm.Engine `json:"db"`
	IdentityId int          `json:"identity_id"`
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) Set(identityId int) { // set方法
	centralKitchenForSchoolUserWithDayDb.Db = Db
	centralKitchenForSchoolUserWithDayDb.IdentityId = identityId
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) GetCentralKitchenForSchoolUserWithDay(id int) (m *model.CentralKitchenForSchoolUserWithDay, err error) {
	m = new(model.CentralKitchenForSchoolUserWithDay)
	has, err := centralKitchenForSchoolUserWithDayDb.Db.Where("id =?", id).Get(m)
	if err != nil {
		return nil, logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return m, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) FindCentralKitchenForSchoolUserWithDayByDate(sDate, eDate string) (*[]model.CentralKitchenForSchoolUserWithDay, error) {
	var m []model.CentralKitchenForSchoolUserWithDay
	if err := centralKitchenForSchoolUserWithDayDb.Db.Where("identity_id =?", centralKitchenForSchoolUserWithDayDb.IdentityId).
		And("date >= ? And date <= ?", sDate, eDate).Asc("date").Find(&m); err != nil {
		return nil, logx.Error(err)
	}
	return &m, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) FindCentralKitchenForSchoolUserWithDayByOrdNo(ordNo string) ([]map[string]interface{}, error) {
	var m []*CentralKitchenForSchoolUserWithDayWithCentralKitchenForSchoolUserRefundDay
	if err := centralKitchenForSchoolUserWithDayDb.Db.Where("central_kitchen_for_school_user_with_day.ord_no =?", ordNo).
		Join("LEFT", "central_kitchen_for_school_user_refund_day", "central_kitchen_for_school_user_with_day.id = central_kitchen_for_school_user_refund_day.records_id").
		Desc("central_kitchen_for_school_user_refund_day.id").
		Find(&m); err != nil {
		return nil, logx.Error(err)
	}
	var resp []map[string]interface{}
	for _, v := range m {
		resp = append(resp, map[string]interface{}{
			"id":            v.CentralKitchenForSchoolUserWithDay.Id,
			"ord_no":        v.CentralKitchenForSchoolUserWithDay.OrdNo,
			"uid":           v.CentralKitchenForSchoolUserWithDay.Uid,
			"enterprise_id": v.CentralKitchenForSchoolUserWithDay.EnterpriseId,
			"identity_id":   v.CentralKitchenForSchoolUserWithDay.IdentityId,
			"kind":          v.CentralKitchenForSchoolUserWithDay.Kind,
			"amount":        v.CentralKitchenForSchoolUserWithDay.Amount,
			"date":          v.CentralKitchenForSchoolUserWithDay.Date,
			"state":         v.CentralKitchenForSchoolUserWithDay.State,
			"refund_date":   v.CentralKitchenForSchoolUserRefundDay.RefundDate,
		})
	}
	return resp, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) CountCentralKitchenForSchoolUserWithDayByOrdNo(ordNo string, state int) (count int64, err error) {
	var m model.CentralKitchenForSchoolUserWithDay
	count, err = centralKitchenForSchoolUserWithDayDb.Db.Where("ord_no =?", ordNo).And("state !=?", state).Count(&m)
	return count, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) CountCentralKitchenForSchoolUserWithDayByOrdNoAndKind(ordNo string, kind, state int) (count int64, err error) {
	var m model.CentralKitchenForSchoolUserWithDay
	count, err = centralKitchenForSchoolUserWithDayDb.Db.Where("ord_no =?", ordNo).And("kind =?", kind).And("state !=?", state).Count(&m)
	return count, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) FindCentralKitchenForSchoolUserWithDayByOrdNoAndState(ordNo string, state int) (*[]model.CentralKitchenForSchoolUserWithDay, error) {
	var m []model.CentralKitchenForSchoolUserWithDay
	if err := centralKitchenForSchoolUserWithDayDb.Db.Where("ord_no =?", ordNo).And("state =?", state).Desc("id").Find(&m); err != nil {
		return nil, logx.Error(err)
	}
	return &m, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) CentralKitchenForSchoolUserWithDayInsert(m *model.CentralKitchenForSchoolUserWithDay) (int, error) {
	_, err := centralKitchenForSchoolUserWithDayDb.Db.InsertOne(m)
	if err != nil {
		return 0, err
	}
	return m.Id, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) BatchAddCentralKitchenForSchoolUserWithDays(mm []*model.CentralKitchenForSchoolUserWithDay) (int64, error) {
	affected, err := centralKitchenForSchoolUserWithDayDb.Db.Insert(mm)
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) CentralKitchenForSchoolUserWithDayDelete(id interface{}) (int64, error) {
	if reflect.TypeOf(id).Kind() == reflect.Slice {
		return Db.In("id", id).Delete(model.CentralKitchenForSchoolUserWithDay{})
	} else {
		return Db.Where("id = ?", id).Delete(model.CentralKitchenForSchoolUserWithDay{})
	}
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) CentralKitchenForSchoolUserWithDayUpdate(id interface{}, m *model.CentralKitchenForSchoolUserWithDay, forceColums ...string) (int64, error) {
	var (
		affected int64
		err      error
	)
	if forceColums != nil {
		affected, err = centralKitchenForSchoolUserWithDayDb.Db.Where("id=?", id).Cols(forceColums...).Update(m)
	} else {
		affected, err = centralKitchenForSchoolUserWithDayDb.Db.Where("id=?", id).Update(m)
	}
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (centralKitchenForSchoolUserWithDayDb *CentralKitchenForSchoolUserWithDayDb) CentralKitchenForSchoolUserWithDayBatchUpdate(ids interface{}, m []*model.CentralKitchenForSchoolUserWithDay) (int64, error) {
	var (
		affected int64
		err      error
	)
	affected, err = centralKitchenForSchoolUserWithDayDb.Db.In("id", ids).Update(m)
	if err != nil {
		return 0, err
	}
	return affected, nil
}
